@@ -1,6 +1,9 @@
 from . import (
     common_cfg,
     annexrepo,
+    clone,
+    clone_ria,
+    clone_ephemeral,
     configuration,
     create_sibling_ghlike,
     push_to_export_remote,
